#[non_exhaustive]pub struct AcceptConnectionProposalInput {
pub attach_point: Option<AttachPoint>,
pub activation_key: Option<String>,
pub description: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attach_point: Option<AttachPoint>The Attach Point to which the connection should be associated.
activation_key: Option<String>An Activation Key that was generated on a supported partner's portal. This key captures the desired parameters from the initial creation request.
The details of this request can be described using with DescribeConnectionProposal.
description: Option<String>A description to distinguish this Connection.
The tags to associate with the resulting Connection.
client_token: Option<String>Idempotency token used for the request.
Implementations
Sourceimpl AcceptConnectionProposalInput
impl AcceptConnectionProposalInput
Sourcepub fn attach_point(&self) -> Option<&AttachPoint>
pub fn attach_point(&self) -> Option<&AttachPoint>
The Attach Point to which the connection should be associated.
Sourcepub fn activation_key(&self) -> Option<&str>
pub fn activation_key(&self) -> Option<&str>
An Activation Key that was generated on a supported partner's portal. This key captures the desired parameters from the initial creation request.
The details of this request can be described using with DescribeConnectionProposal.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description to distinguish this Connection.
The tags to associate with the resulting Connection.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Idempotency token used for the request.
Sourceimpl AcceptConnectionProposalInput
impl AcceptConnectionProposalInput
Sourcepub fn builder() -> AcceptConnectionProposalInputBuilder
pub fn builder() -> AcceptConnectionProposalInputBuilder
Creates a new builder-style object to manufacture AcceptConnectionProposalInput.