#[non_exhaustive]pub struct CreateConnectionInputBuilder { /* private fields */ }Expand description
A builder for CreateConnectionInput.
Implementations
Sourceimpl CreateConnectionInputBuilder
impl CreateConnectionInputBuilder
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description to distinguish this Connection.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description to distinguish this Connection.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description to distinguish this Connection.
Sourcepub fn bandwidth(self, input: impl Into<String>) -> Self
pub fn bandwidth(self, input: impl Into<String>) -> Self
The desired bandwidth of the requested Connection
Sourcepub fn set_bandwidth(self, input: Option<String>) -> Self
pub fn set_bandwidth(self, input: Option<String>) -> Self
The desired bandwidth of the requested Connection
Sourcepub fn get_bandwidth(&self) -> &Option<String>
pub fn get_bandwidth(&self) -> &Option<String>
The desired bandwidth of the requested Connection
Sourcepub fn attach_point(self, input: AttachPoint) -> Self
pub fn attach_point(self, input: AttachPoint) -> Self
The Attach Point to which the connection should be associated."
This field is required.Sourcepub fn set_attach_point(self, input: Option<AttachPoint>) -> Self
pub fn set_attach_point(self, input: Option<AttachPoint>) -> Self
The Attach Point to which the connection should be associated."
Sourcepub fn get_attach_point(&self) -> &Option<AttachPoint>
pub fn get_attach_point(&self) -> &Option<AttachPoint>
The Attach Point to which the connection should be associated."
Sourcepub fn environment_id(self, input: impl Into<String>) -> Self
pub fn environment_id(self, input: impl Into<String>) -> Self
The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
Sourcepub fn set_environment_id(self, input: Option<String>) -> Self
pub fn set_environment_id(self, input: Option<String>) -> Self
The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
Sourcepub fn get_environment_id(&self) -> &Option<String>
pub fn get_environment_id(&self) -> &Option<String>
The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
Sourcepub fn remote_account(self, input: RemoteAccountIdentifier) -> Self
pub fn remote_account(self, input: RemoteAccountIdentifier) -> Self
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
Sourcepub fn set_remote_account(self, input: Option<RemoteAccountIdentifier>) -> Self
pub fn set_remote_account(self, input: Option<RemoteAccountIdentifier>) -> Self
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
Sourcepub fn get_remote_account(&self) -> &Option<RemoteAccountIdentifier>
pub fn get_remote_account(&self) -> &Option<RemoteAccountIdentifier>
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tag to associate with the resulting Connection.
The tag to associate with the resulting Connection.
The tag to associate with the resulting Connection.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Idempotency token used for the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Idempotency token used for the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Idempotency token used for the request.
Sourcepub fn build(self) -> Result<CreateConnectionInput, BuildError>
pub fn build(self) -> Result<CreateConnectionInput, BuildError>
Consumes the builder and constructs a CreateConnectionInput.
Sourceimpl CreateConnectionInputBuilder
impl CreateConnectionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateConnectionOutput, SdkError<CreateConnectionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateConnectionOutput, SdkError<CreateConnectionError, HttpResponse>>
Sends a request with this input using the given client.