#[non_exhaustive]pub struct CreateConnectionInput {
pub description: Option<String>,
pub bandwidth: Option<String>,
pub attach_point: Option<AttachPoint>,
pub environment_id: Option<String>,
pub remote_account: Option<RemoteAccountIdentifier>,
pub tags: Option<HashMap<String, String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>A description to distinguish this Connection.
bandwidth: Option<String>The desired bandwidth of the requested Connection
attach_point: Option<AttachPoint>The Attach Point to which the connection should be associated."
environment_id: Option<String>The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
remote_account: Option<RemoteAccountIdentifier>Account and/or principal identifying information that can be verified by the partner of this specific Environment.
The tag to associate with the resulting Connection.
client_token: Option<String>Idempotency token used for the request.
Implementations
Sourceimpl CreateConnectionInput
impl CreateConnectionInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description to distinguish this Connection.
Sourcepub fn attach_point(&self) -> Option<&AttachPoint>
pub fn attach_point(&self) -> Option<&AttachPoint>
The Attach Point to which the connection should be associated."
Sourcepub fn environment_id(&self) -> Option<&str>
pub fn environment_id(&self) -> Option<&str>
The identifier of the Environment across which this Connection should be created.
The available Environment objects can be determined using ListEnvironments.
Sourcepub fn remote_account(&self) -> Option<&RemoteAccountIdentifier>
pub fn remote_account(&self) -> Option<&RemoteAccountIdentifier>
Account and/or principal identifying information that can be verified by the partner of this specific Environment.
The tag to associate with the resulting Connection.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Idempotency token used for the request.
Sourceimpl CreateConnectionInput
impl CreateConnectionInput
Sourcepub fn builder() -> CreateConnectionInputBuilder
pub fn builder() -> CreateConnectionInputBuilder
Creates a new builder-style object to manufacture CreateConnectionInput.