#[non_exhaustive]pub enum DescribeConnectionProposalError {
AccessDeniedException(AccessDeniedException),
InterconnectClientException(InterconnectClientException),
InterconnectServerException(InterconnectServerException),
InterconnectValidationException(InterconnectValidationException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the DescribeConnectionProposalError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
The calling principal is not allowed to access the specified resource, or the resource does not exist.
InterconnectClientException(InterconnectClientException)
The request was denied due to incorrect client supplied parameters.
InterconnectServerException(InterconnectServerException)
The request resulted in an exception internal to the service.
InterconnectValidationException(InterconnectValidationException)
The input fails to satisfy the constraints specified.
ResourceNotFoundException(ResourceNotFoundException)
The request specifies a resource that does not exist on the server.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The requested operation would result in the calling principal exceeding their allotted quota.
ThrottlingException(ThrottlingException)
The request was denied due to request throttling.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DescribeConnectionProposalError
impl DescribeConnectionProposalError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DescribeConnectionProposalError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DescribeConnectionProposalError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::AccessDeniedException.
Sourcepub fn is_interconnect_client_exception(&self) -> bool
pub fn is_interconnect_client_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::InterconnectClientException.
Sourcepub fn is_interconnect_server_exception(&self) -> bool
pub fn is_interconnect_server_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::InterconnectServerException.
Sourcepub fn is_interconnect_validation_exception(&self) -> bool
pub fn is_interconnect_validation_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::InterconnectValidationException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::ResourceNotFoundException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::ServiceQuotaExceededException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is DescribeConnectionProposalError::ThrottlingException.