pub struct Client { /* private fields */ }Expand description
Client for Interconnect
Client for invoking operations on Interconnect. Each operation on Interconnect is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_interconnect::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_interconnect::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the AcceptConnectionProposal operation has
a Client::accept_connection_proposal, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.accept_connection_proposal()
.activation_key("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Waiters
This client provides wait_until methods behind the Waiters trait.
To use them, simply import the trait, and then call one of the wait_until methods. This will
return a waiter fluent builder that takes various parameters, which are documented on the builder
type. Once parameters have been provided, the wait method can be called to initiate waiting.
For example, if there was a wait_until_thing method, it could look like:
let result = client.wait_until_thing()
.thing_id("someId")
.wait(Duration::from_secs(120))
.await;Implementations
Sourceimpl Client
impl Client
Sourcepub fn accept_connection_proposal(
&self,
) -> AcceptConnectionProposalFluentBuilder
pub fn accept_connection_proposal( &self, ) -> AcceptConnectionProposalFluentBuilder
Constructs a fluent builder for the AcceptConnectionProposal operation.
- The fluent builder is configurable:
attach_point(AttachPoint)/set_attach_point(Option<AttachPoint>):
required: trueThe Attach Point to which the connection should be associated.
activation_key(impl Into<String>)/set_activation_key(Option<String>):
required: trueAn Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.
The details of this request can be described using with
DescribeConnectionProposal.description(impl Into<String>)/set_description(Option<String>):
required: falseA description to distinguish this
Connection.tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseThe tags to associate with the resulting
Connection.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseIdempotency token used for the request.
- On success, responds with
AcceptConnectionProposalOutputwith field(s):connection(Option<Connection>):The created
Connectionobject.
- On failure, responds with
SdkError<AcceptConnectionProposalError>
Sourceimpl Client
impl Client
Sourcepub fn create_connection(&self) -> CreateConnectionFluentBuilder
pub fn create_connection(&self) -> CreateConnectionFluentBuilder
Constructs a fluent builder for the CreateConnection operation.
- The fluent builder is configurable:
description(impl Into<String>)/set_description(Option<String>):
required: falseA description to distinguish this
Connection.bandwidth(impl Into<String>)/set_bandwidth(Option<String>):
required: trueThe desired bandwidth of the requested
Connectionattach_point(AttachPoint)/set_attach_point(Option<AttachPoint>):
required: trueThe Attach Point to which the connection should be associated.“
environment_id(impl Into<String>)/set_environment_id(Option<String>):
required: trueThe identifier of the
Environmentacross which thisConnectionshould be created.The available
Environmentobjects can be determined usingListEnvironments.remote_account(RemoteAccountIdentifier)/set_remote_account(Option<RemoteAccountIdentifier>):
required: falseAccount and/or principal identifying information that can be verified by the partner of this specific Environment.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseThe tag to associate with the resulting
Connection.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseIdempotency token used for the request.
- On success, responds with
CreateConnectionOutputwith field(s):connection(Option<Connection>):The resulting
Connection.
- On failure, responds with
SdkError<CreateConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn delete_connection(&self) -> DeleteConnectionFluentBuilder
pub fn delete_connection(&self) -> DeleteConnectionFluentBuilder
Constructs a fluent builder for the DeleteConnection operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: trueThe identifier of the
Connectionto be deleted.client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseIdempotency token used for the request.
- On success, responds with
DeleteConnectionOutputwith field(s):connection(Option<Connection>):The
Connectionobject that has been marked for deletion.
- On failure, responds with
SdkError<DeleteConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn describe_connection_proposal(
&self,
) -> DescribeConnectionProposalFluentBuilder
pub fn describe_connection_proposal( &self, ) -> DescribeConnectionProposalFluentBuilder
Constructs a fluent builder for the DescribeConnectionProposal operation.
- The fluent builder is configurable:
activation_key(impl Into<String>)/set_activation_key(Option<String>):
required: trueAn Activation Key that was generated on a supported partner’s portal. This key captures the desired parameters from the initial creation request.
- On success, responds with
DescribeConnectionProposalOutputwith field(s):bandwidth(String):The bandwidth of the proposed
Connection.environment_id(String):The identifier of the
Environmentupon which theConnectionwould be placed if this proposal were accepted.provider(Option<Provider>):The partner provider of the specific
Environmentof the proposal.location(String):The partner specific location distinguisher of the specific
Environmentof the proposal.
- On failure, responds with
SdkError<DescribeConnectionProposalError>
Sourceimpl Client
impl Client
Sourcepub fn get_connection(&self) -> GetConnectionFluentBuilder
pub fn get_connection(&self) -> GetConnectionFluentBuilder
Constructs a fluent builder for the GetConnection operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: trueThe identifier of the requested
Connection
- On success, responds with
GetConnectionOutputwith field(s):connection(Option<Connection>):The existing
Connectionresource.
- On failure, responds with
SdkError<GetConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn get_environment(&self) -> GetEnvironmentFluentBuilder
pub fn get_environment(&self) -> GetEnvironmentFluentBuilder
Constructs a fluent builder for the GetEnvironment operation.
- The fluent builder is configurable:
id(impl Into<String>)/set_id(Option<String>):
required: trueThe identifier of the specific
Environmentto describe.
- On success, responds with
GetEnvironmentOutputwith field(s):environment(Option<Environment>):The requested
Environmentstructure.
- On failure, responds with
SdkError<GetEnvironmentError>
Sourceimpl Client
impl Client
Sourcepub fn list_attach_points(&self) -> ListAttachPointsFluentBuilder
pub fn list_attach_points(&self) -> ListAttachPointsFluentBuilder
Constructs a fluent builder for the ListAttachPoints operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
environment_id(impl Into<String>)/set_environment_id(Option<String>):
required: trueThe identifier of the
Environmentfor which to list valid Attach Points.max_results(i32)/set_max_results(Option<i32>):
required: falseThe max number of list results in a single paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA pagination token from a previous paginated response indicating you wish to get the next page.
- On success, responds with
ListAttachPointsOutputwith field(s):attach_points(Vec::<AttachPointDescriptor>):The valid
AttachPointnext_token(Option<String>):A pagination token indicating that there are more results that can be fetched.
- On failure, responds with
SdkError<ListAttachPointsError>
Sourceimpl Client
impl Client
Sourcepub fn list_connections(&self) -> ListConnectionsFluentBuilder
pub fn list_connections(&self) -> ListConnectionsFluentBuilder
Constructs a fluent builder for the ListConnections operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseThe max number of list results in a single paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA pagination token from a previous paginated response indicating you wish to get the next page of results.
state(ConnectionState)/set_state(Option<ConnectionState>):
required: falseFilter the results to only include
Connectionobjects in the givenConnection$state.environment_id(impl Into<String>)/set_environment_id(Option<String>):
required: falseFilter the results to only include
Connectionobjects on the givenEnvironment.provider(Provider)/set_provider(Option<Provider>):
required: falseFilter the results to only include
Connectionobjects to the givenProvider.attach_point(AttachPoint)/set_attach_point(Option<AttachPoint>):
required: falseFilter results to only include
Connectionobjects attached to the givenAttachPoint.
- On success, responds with
ListConnectionsOutputwith field(s):connections(Option<Vec::<ConnectionSummary>>):The resulting list of
Connectionobjects.next_token(Option<String>):A pagination token for use in subsequent calls to fetch the next page of results.
- On failure, responds with
SdkError<ListConnectionsError>
Sourceimpl Client
impl Client
Sourcepub fn list_environments(&self) -> ListEnvironmentsFluentBuilder
pub fn list_environments(&self) -> ListEnvironmentsFluentBuilder
Constructs a fluent builder for the ListEnvironments operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseThe max number of list results in a single paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseA pagination token from a previous paginated response indicating you wish to get the next page of results.
provider(Provider)/set_provider(Option<Provider>):
required: falseFilter results to only include
Environmentobjects that connect to theProvider.location(impl Into<String>)/set_location(Option<String>):
required: falseFilter results to only include
Environmentobjects that connect to a given location distiguisher.
- On success, responds with
ListEnvironmentsOutputwith field(s):environments(Vec::<Environment>):The list of matching
Environmentobjects.next_token(Option<String>):A pagination token for use in subsequent calls to fetch the next page of results.
- On failure, responds with
SdkError<ListEnvironmentsError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe resource ARN for which to list tags.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap::<String, String>>):The tags on the specified ARN.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the resource that should receive the new tags.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: trueA map of tags to apply to the specified resource.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
arn(impl Into<String>)/set_arn(Option<String>):
required: trueThe ARN of the resource from which the specified tags should be removed.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: trueThe list of tag keys that should be removed from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn update_connection(&self) -> UpdateConnectionFluentBuilder
pub fn update_connection(&self) -> UpdateConnectionFluentBuilder
Constructs a fluent builder for the UpdateConnection operation.
- The fluent builder is configurable:
identifier(impl Into<String>)/set_identifier(Option<String>):
required: trueThe identifier of the
Connectionthat should be updated.description(impl Into<String>)/set_description(Option<String>):
required: falseAn updated description to apply to the
Connectionbandwidth(impl Into<String>)/set_bandwidth(Option<String>):
required: falseRequest a new bandwidth size on the given
Connection.Note that changes to the size may be subject to additional policy, and does require the remote partner provider to acknowledge and permit this new bandwidth size.
client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseIdempotency token used for the request.
- On success, responds with
UpdateConnectionOutputwith field(s):connection(Option<Connection>):The resulting updated
Connection
- On failure, responds with
SdkError<UpdateConnectionError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.