#[non_exhaustive]pub struct BandwidthsBuilder { /* private fields */ }Expand description
A builder for Bandwidths.
Implementations
Sourceimpl BandwidthsBuilder
impl BandwidthsBuilder
Sourcepub fn available(self, input: impl Into<String>) -> Self
pub fn available(self, input: impl Into<String>) -> Self
Appends an item to available.
To override the contents of this collection use set_available.
The list of currently available bandwidths.
Sourcepub fn set_available(self, input: Option<Vec<String>>) -> Self
pub fn set_available(self, input: Option<Vec<String>>) -> Self
The list of currently available bandwidths.
Sourcepub fn get_available(&self) -> &Option<Vec<String>>
pub fn get_available(&self) -> &Option<Vec<String>>
The list of currently available bandwidths.
Sourcepub fn supported(self, input: impl Into<String>) -> Self
pub fn supported(self, input: impl Into<String>) -> Self
Appends an item to supported.
To override the contents of this collection use set_supported.
The list of all bandwidths that this environment plans to support
Sourcepub fn set_supported(self, input: Option<Vec<String>>) -> Self
pub fn set_supported(self, input: Option<Vec<String>>) -> Self
The list of all bandwidths that this environment plans to support
Sourcepub fn get_supported(&self) -> &Option<Vec<String>>
pub fn get_supported(&self) -> &Option<Vec<String>>
The list of all bandwidths that this environment plans to support
Sourcepub fn build(self) -> Bandwidths
pub fn build(self) -> Bandwidths
Consumes the builder and constructs a Bandwidths.