#[non_exhaustive]pub struct ConnectionSummaryBuilder { /* private fields */ }Expand description
A builder for ConnectionSummary.
Implementations
Sourceimpl ConnectionSummaryBuilder
impl ConnectionSummaryBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The identifier of the requested Connection
Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The ARN of the Connection
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A descriptive name of the Connection
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A descriptive name of the Connection
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A descriptive name of the Connection
Sourcepub fn bandwidth(self, input: impl Into<String>) -> Self
pub fn bandwidth(self, input: impl Into<String>) -> Self
The bandwidth of the Connection
Sourcepub fn set_bandwidth(self, input: Option<String>) -> Self
pub fn set_bandwidth(self, input: Option<String>) -> Self
The bandwidth of the Connection
Sourcepub fn get_bandwidth(&self) -> &Option<String>
pub fn get_bandwidth(&self) -> &Option<String>
The bandwidth of the Connection
Sourcepub fn attach_point(self, input: AttachPoint) -> Self
pub fn attach_point(self, input: AttachPoint) -> Self
The Attach Point to which the connection should be associated.
This field is required.Sourcepub fn set_attach_point(self, input: Option<AttachPoint>) -> Self
pub fn set_attach_point(self, input: Option<AttachPoint>) -> Self
The Attach Point to which the connection should be associated.
Sourcepub fn get_attach_point(&self) -> &Option<AttachPoint>
pub fn get_attach_point(&self) -> &Option<AttachPoint>
The Attach Point to which the connection should be associated.
Sourcepub fn environment_id(self, input: impl Into<String>) -> Self
pub fn environment_id(self, input: impl Into<String>) -> Self
The Environment that this Connection is created on.
Sourcepub fn set_environment_id(self, input: Option<String>) -> Self
pub fn set_environment_id(self, input: Option<String>) -> Self
The Environment that this Connection is created on.
Sourcepub fn get_environment_id(&self) -> &Option<String>
pub fn get_environment_id(&self) -> &Option<String>
The Environment that this Connection is created on.
Sourcepub fn provider(self, input: Provider) -> Self
pub fn provider(self, input: Provider) -> Self
The provider on the remote end of this Connection
Sourcepub fn set_provider(self, input: Option<Provider>) -> Self
pub fn set_provider(self, input: Option<Provider>) -> Self
The provider on the remote end of this Connection
Sourcepub fn get_provider(&self) -> &Option<Provider>
pub fn get_provider(&self) -> &Option<Provider>
The provider on the remote end of this Connection
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
The provider specific location at the remote end of this Connection
Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
The provider specific location at the remote end of this Connection
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
The provider specific location at the remote end of this Connection
Sourcepub fn type(self, input: impl Into<String>) -> Self
pub fn type(self, input: impl Into<String>) -> Self
The product variant supplied by this resource.
This field is required.Sourcepub fn set_type(self, input: Option<String>) -> Self
pub fn set_type(self, input: Option<String>) -> Self
The product variant supplied by this resource.
Sourcepub fn state(self, input: ConnectionState) -> Self
pub fn state(self, input: ConnectionState) -> Self
-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
Sourcepub fn set_state(self, input: Option<ConnectionState>) -> Self
pub fn set_state(self, input: Option<ConnectionState>) -> Self
-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
Sourcepub fn get_state(&self) -> &Option<ConnectionState>
pub fn get_state(&self) -> &Option<ConnectionState>
-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
An identifier used by both AWS and the remote partner to identify the specific connection.
This field is required.An identifier used by both AWS and the remote partner to identify the specific connection.
An identifier used by both AWS and the remote partner to identify the specific connection.
Sourcepub fn billing_tier(self, input: i32) -> Self
pub fn billing_tier(self, input: i32) -> Self
The billing tier this connection is currently assigned.
Sourcepub fn set_billing_tier(self, input: Option<i32>) -> Self
pub fn set_billing_tier(self, input: Option<i32>) -> Self
The billing tier this connection is currently assigned.
Sourcepub fn get_billing_tier(&self) -> &Option<i32>
pub fn get_billing_tier(&self) -> &Option<i32>
The billing tier this connection is currently assigned.
Sourcepub fn build(self) -> Result<ConnectionSummary, BuildError>
pub fn build(self) -> Result<ConnectionSummary, BuildError>
Consumes the builder and constructs a ConnectionSummary.
This method will fail if any of the following fields are not set: