#[non_exhaustive]pub struct EnvironmentBuilder { /* private fields */ }Expand description
A builder for Environment.
Implementations
Sourceimpl EnvironmentBuilder
impl EnvironmentBuilder
Sourcepub fn provider(self, input: Provider) -> Self
pub fn provider(self, input: Provider) -> Self
The provider on the remote side of this Connection.
Sourcepub fn set_provider(self, input: Option<Provider>) -> Self
pub fn set_provider(self, input: Option<Provider>) -> Self
The provider on the remote side of this Connection.
Sourcepub fn get_provider(&self) -> &Option<Provider>
pub fn get_provider(&self) -> &Option<Provider>
The provider on the remote side of this Connection.
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
The provider specific location on the remote side of this Connection.
Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
The provider specific location on the remote side of this Connection.
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
The provider specific location on the remote side of this Connection.
Sourcepub fn environment_id(self, input: impl Into<String>) -> Self
pub fn environment_id(self, input: impl Into<String>) -> Self
The identifier of this Environment
Sourcepub fn set_environment_id(self, input: Option<String>) -> Self
pub fn set_environment_id(self, input: Option<String>) -> Self
The identifier of this Environment
Sourcepub fn get_environment_id(&self) -> &Option<String>
pub fn get_environment_id(&self) -> &Option<String>
The identifier of this Environment
Sourcepub fn state(self, input: EnvironmentState) -> Self
pub fn state(self, input: EnvironmentState) -> Self
The state of the Environment. Possible values:
-
available: The environment is available and newConnectionobjects can be requested. -
limited: The environment is available, but overall capacity is limited. The set of available bandwidths -
unavailable: The environment is currently unavailable.
Sourcepub fn set_state(self, input: Option<EnvironmentState>) -> Self
pub fn set_state(self, input: Option<EnvironmentState>) -> Self
The state of the Environment. Possible values:
-
available: The environment is available and newConnectionobjects can be requested. -
limited: The environment is available, but overall capacity is limited. The set of available bandwidths -
unavailable: The environment is currently unavailable.
Sourcepub fn get_state(&self) -> &Option<EnvironmentState>
pub fn get_state(&self) -> &Option<EnvironmentState>
The state of the Environment. Possible values:
-
available: The environment is available and newConnectionobjects can be requested. -
limited: The environment is available, but overall capacity is limited. The set of available bandwidths -
unavailable: The environment is currently unavailable.
Sourcepub fn bandwidths(self, input: Bandwidths) -> Self
pub fn bandwidths(self, input: Bandwidths) -> Self
The sets of bandwidths that are available and supported on this environment.
This field is required.Sourcepub fn set_bandwidths(self, input: Option<Bandwidths>) -> Self
pub fn set_bandwidths(self, input: Option<Bandwidths>) -> Self
The sets of bandwidths that are available and supported on this environment.
Sourcepub fn get_bandwidths(&self) -> &Option<Bandwidths>
pub fn get_bandwidths(&self) -> &Option<Bandwidths>
The sets of bandwidths that are available and supported on this environment.
Sourcepub fn type(self, input: impl Into<String>) -> Self
pub fn type(self, input: impl Into<String>) -> Self
The specific product type of Connection objects provided by this Environment.
Sourcepub fn set_type(self, input: Option<String>) -> Self
pub fn set_type(self, input: Option<String>) -> Self
The specific product type of Connection objects provided by this Environment.
Sourcepub fn get_type(&self) -> &Option<String>
pub fn get_type(&self) -> &Option<String>
The specific product type of Connection objects provided by this Environment.
Sourcepub fn activation_page_url(self, input: impl Into<String>) -> Self
pub fn activation_page_url(self, input: impl Into<String>) -> Self
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
Sourcepub fn set_activation_page_url(self, input: Option<String>) -> Self
pub fn set_activation_page_url(self, input: Option<String>) -> Self
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
Sourcepub fn get_activation_page_url(&self) -> &Option<String>
pub fn get_activation_page_url(&self) -> &Option<String>
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
Sourcepub fn remote_identifier_type(self, input: RemoteAccountIdentifierType) -> Self
pub fn remote_identifier_type(self, input: RemoteAccountIdentifierType) -> Self
The type of identifying information that should be supplied to the remoteAccount parameter of a CreateConnection call for this specific Environment.
Sourcepub fn set_remote_identifier_type(
self,
input: Option<RemoteAccountIdentifierType>,
) -> Self
pub fn set_remote_identifier_type( self, input: Option<RemoteAccountIdentifierType>, ) -> Self
The type of identifying information that should be supplied to the remoteAccount parameter of a CreateConnection call for this specific Environment.
Sourcepub fn get_remote_identifier_type(&self) -> &Option<RemoteAccountIdentifierType>
pub fn get_remote_identifier_type(&self) -> &Option<RemoteAccountIdentifierType>
The type of identifying information that should be supplied to the remoteAccount parameter of a CreateConnection call for this specific Environment.
Sourcepub fn build(self) -> Result<Environment, BuildError>
pub fn build(self) -> Result<Environment, BuildError>
Consumes the builder and constructs a Environment.
This method will fail if any of the following fields are not set: