#[non_exhaustive]pub enum RemoteAccountIdentifier {
Identifier(String),
#[non_exhaustive] Unknown,
}Expand description
The types of identifiers that may be needed for remote account specification.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Identifier(String)
A generic bit of identifying information. Can be used in place of any of the more specific types.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl RemoteAccountIdentifier
impl RemoteAccountIdentifier
Sourcepub fn as_identifier(&self) -> Result<&String, &Self>
pub fn as_identifier(&self) -> Result<&String, &Self>
Tries to convert the enum instance into Identifier, extracting the inner String.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_identifier(&self) -> bool
pub fn is_identifier(&self) -> bool
Returns true if this is a Identifier.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.