#[non_exhaustive]pub struct AttachPointDescriptor {
pub type: AttachPointType,
pub identifier: String,
pub name: String,
}Expand description
Describes a possible Attach Point for a Connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: AttachPointTypeThe type of this AttachPoint, which will dictate the syntax of the identifier.
Current types include:
-
ARN
-
DirectConnect Gateway
identifier: StringThe identifier for the specific type of the AttachPoint.
name: StringThe descriptive name of the identifier attach point.
Implementations
Sourceimpl AttachPointDescriptor
impl AttachPointDescriptor
Sourcepub fn type(&self) -> &AttachPointType
pub fn type(&self) -> &AttachPointType
The type of this AttachPoint, which will dictate the syntax of the identifier.
Current types include:
-
ARN
-
DirectConnect Gateway
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
The identifier for the specific type of the AttachPoint.
Sourceimpl AttachPointDescriptor
impl AttachPointDescriptor
Sourcepub fn builder() -> AttachPointDescriptorBuilder
pub fn builder() -> AttachPointDescriptorBuilder
Creates a new builder-style object to manufacture AttachPointDescriptor.