#[non_exhaustive]pub struct Bandwidths {
pub available: Option<Vec<String>>,
pub supported: Option<Vec<String>>,
}Expand description
Contains the details about the available and supported bandwidths.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.available: Option<Vec<String>>The list of currently available bandwidths.
supported: Option<Vec<String>>The list of all bandwidths that this environment plans to support
Implementations
Sourceimpl Bandwidths
impl Bandwidths
Sourceimpl Bandwidths
impl Bandwidths
Sourcepub fn builder() -> BandwidthsBuilder
pub fn builder() -> BandwidthsBuilder
Creates a new builder-style object to manufacture Bandwidths.