#[non_exhaustive]pub struct Connection {Show 15 fields
pub id: String,
pub arn: String,
pub description: String,
pub bandwidth: String,
pub attach_point: Option<AttachPoint>,
pub environment_id: String,
pub provider: Option<Provider>,
pub location: String,
pub type: String,
pub state: ConnectionState,
pub shared_id: String,
pub billing_tier: Option<i32>,
pub owner_account: String,
pub activation_key: String,
pub tags: Option<HashMap<String, String>>,
}Expand description
The object describing the provided connectivity from the AWS region to the partner location.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe short identifier of the connection object.
arn: StringAn ARN of a Connection object.
description: StringA descriptive name for the connection.
bandwidth: StringThe specific selected bandwidth of this connection.
attach_point: Option<AttachPoint>The Attach Point to which the connection should be associated."
environment_id: StringThe specific Environment this connection is placed upon.
provider: Option<Provider>The provider on the remote side of this Connection.
location: StringThe provider specific location on the remote side of this Connection
type: StringThe specific product type of this Connection.
state: ConnectionState-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
An identifier used by both AWS and the remote partner to identify the specific connection.
billing_tier: Option<i32>The billing tier this connection is currently assigned.
owner_account: StringThe account that owns this Connection
activation_key: StringThe Activation Key associated to this connection.
The tags on the Connection
Implementations
Sourceimpl Connection
impl Connection
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A descriptive name for the connection.
Sourcepub fn attach_point(&self) -> Option<&AttachPoint>
pub fn attach_point(&self) -> Option<&AttachPoint>
The Attach Point to which the connection should be associated."
Sourcepub fn environment_id(&self) -> &str
pub fn environment_id(&self) -> &str
The specific Environment this connection is placed upon.
Sourcepub fn provider(&self) -> Option<&Provider>
pub fn provider(&self) -> Option<&Provider>
The provider on the remote side of this Connection.
Sourcepub fn location(&self) -> &str
pub fn location(&self) -> &str
The provider specific location on the remote side of this Connection
Sourcepub fn state(&self) -> &ConnectionState
pub fn state(&self) -> &ConnectionState
-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
An identifier used by both AWS and the remote partner to identify the specific connection.
Sourcepub fn billing_tier(&self) -> Option<i32>
pub fn billing_tier(&self) -> Option<i32>
The billing tier this connection is currently assigned.
Sourcepub fn owner_account(&self) -> &str
pub fn owner_account(&self) -> &str
The account that owns this Connection
Sourcepub fn activation_key(&self) -> &str
pub fn activation_key(&self) -> &str
The Activation Key associated to this connection.
The tags on the Connection
Sourceimpl Connection
impl Connection
Sourcepub fn builder() -> ConnectionBuilder
pub fn builder() -> ConnectionBuilder
Creates a new builder-style object to manufacture Connection.