#[non_exhaustive]pub struct ConnectionSummary {
pub id: String,
pub arn: String,
pub description: String,
pub bandwidth: String,
pub attach_point: Option<AttachPoint>,
pub environment_id: String,
pub provider: Option<Provider>,
pub location: String,
pub type: String,
pub state: ConnectionState,
pub shared_id: String,
pub billing_tier: Option<i32>,
}Expand description
Summarized view of a Connection object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe identifier of the requested Connection
arn: StringThe ARN of the Connection
description: StringA descriptive name of the Connection
bandwidth: StringThe bandwidth of the Connection
attach_point: Option<AttachPoint>The Attach Point to which the connection should be associated.
environment_id: StringThe Environment that this Connection is created on.
provider: Option<Provider>The provider on the remote end of this Connection
location: StringThe provider specific location at the remote end of this Connection
type: StringThe product variant supplied by this resource.
state: ConnectionState-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
An identifier used by both AWS and the remote partner to identify the specific connection.
billing_tier: Option<i32>The billing tier this connection is currently assigned.
Implementations
Sourceimpl ConnectionSummary
impl ConnectionSummary
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A descriptive name of the Connection
Sourcepub fn attach_point(&self) -> Option<&AttachPoint>
pub fn attach_point(&self) -> Option<&AttachPoint>
The Attach Point to which the connection should be associated.
Sourcepub fn environment_id(&self) -> &str
pub fn environment_id(&self) -> &str
The Environment that this Connection is created on.
Sourcepub fn location(&self) -> &str
pub fn location(&self) -> &str
The provider specific location at the remote end of this Connection
Sourcepub fn state(&self) -> &ConnectionState
pub fn state(&self) -> &ConnectionState
-
requested: The initial state of a connection. The state will remain here until the Connection is accepted on the Partner portal. -
pending: The connection has been accepted and is being provisioned between AWS and the Partner. -
available: The connection has been fully provisioned between AWS and the Partner. -
deleting: The connection is being deleted. -
deleted: The connection has been deleted. -
failed: The connection has failed to be created. -
updating: The connection is being updated.
An identifier used by both AWS and the remote partner to identify the specific connection.
Sourcepub fn billing_tier(&self) -> Option<i32>
pub fn billing_tier(&self) -> Option<i32>
The billing tier this connection is currently assigned.
Sourceimpl ConnectionSummary
impl ConnectionSummary
Sourcepub fn builder() -> ConnectionSummaryBuilder
pub fn builder() -> ConnectionSummaryBuilder
Creates a new builder-style object to manufacture ConnectionSummary.