#[non_exhaustive]pub struct Environment {
pub provider: Option<Provider>,
pub location: String,
pub environment_id: String,
pub state: EnvironmentState,
pub bandwidths: Option<Bandwidths>,
pub type: String,
pub activation_page_url: Option<String>,
pub remote_identifier_type: Option<RemoteAccountIdentifierType>,
}Expand description
Defines the logical topology that an AWS Interconnect Connection is created upon.
Specifically, an Environment defines the partner The remote Cloud Service Provider of this resource. or The remote Last Mile Provider of this resource. and the region or location specification to which an AWS Interconnect Connection can be made.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.provider: Option<Provider>The provider on the remote side of this Connection.
location: StringThe provider specific location on the remote side of this Connection.
environment_id: StringThe identifier of this Environment
state: EnvironmentStateThe state of the Environment. Possible values:
-
available: The environment is available and newConnectionobjects can be requested. -
limited: The environment is available, but overall capacity is limited. The set of available bandwidths -
unavailable: The environment is currently unavailable.
bandwidths: Option<Bandwidths>The sets of bandwidths that are available and supported on this environment.
type: StringThe specific product type of Connection objects provided by this Environment.
activation_page_url: Option<String>An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
remote_identifier_type: Option<RemoteAccountIdentifierType>The type of identifying information that should be supplied to the remoteAccount parameter of a CreateConnection call for this specific Environment.
Implementations
Sourceimpl Environment
impl Environment
Sourcepub fn provider(&self) -> Option<&Provider>
pub fn provider(&self) -> Option<&Provider>
The provider on the remote side of this Connection.
Sourcepub fn location(&self) -> &str
pub fn location(&self) -> &str
The provider specific location on the remote side of this Connection.
Sourcepub fn environment_id(&self) -> &str
pub fn environment_id(&self) -> &str
The identifier of this Environment
Sourcepub fn state(&self) -> &EnvironmentState
pub fn state(&self) -> &EnvironmentState
The state of the Environment. Possible values:
-
available: The environment is available and newConnectionobjects can be requested. -
limited: The environment is available, but overall capacity is limited. The set of available bandwidths -
unavailable: The environment is currently unavailable.
Sourcepub fn bandwidths(&self) -> Option<&Bandwidths>
pub fn bandwidths(&self) -> Option<&Bandwidths>
The sets of bandwidths that are available and supported on this environment.
Sourcepub fn type(&self) -> &str
pub fn type(&self) -> &str
The specific product type of Connection objects provided by this Environment.
Sourcepub fn activation_page_url(&self) -> Option<&str>
pub fn activation_page_url(&self) -> Option<&str>
An HTTPS URL on the remote partner portal where the Activation Key should be brought to complete the creation process.
Sourcepub fn remote_identifier_type(&self) -> Option<&RemoteAccountIdentifierType>
pub fn remote_identifier_type(&self) -> Option<&RemoteAccountIdentifierType>
The type of identifying information that should be supplied to the remoteAccount parameter of a CreateConnection call for this specific Environment.
Sourceimpl Environment
impl Environment
Sourcepub fn builder() -> EnvironmentBuilder
pub fn builder() -> EnvironmentBuilder
Creates a new builder-style object to manufacture Environment.